@@ -1,5 +1,5 @@
 
-#############################################################################
+###########################################################################
 calcPCA <- function(X, r=2, eta=10, itmax=200, err=1e-8, normed = TRUE,
                     mySeed=50) {
     d <- ncol(X)
@@ -20,10 +20,11 @@ calcPCA <- function(X, r=2, eta=10, itmax=200, err=1e-8, normed = TRUE,
        std <- apply(Xm, 2, sd)*sqrt((m-1)/m)
        Si <- diag(1/std)
        Xs <- Xm %*% Si
-       res <- calcSVD(Xs, r, eta, itmax, err)
+       colnames(Xs) <- colnames(X)
+       res <- calcSVD(Xs, r)
     } else {
        Xs <- Xm
-       res <- calcSVD(Xs, r, eta, itmax, err)
+       res <- calcSVD(Xs, r)
     }
 
     # PCA results from the SVD results
@@ -38,4 +39,4 @@ calcPCA <- function(X, r=2, eta=10, itmax=200, err=1e-8, normed = TRUE,
 
     list(values=values,vectors=vectors,iter=t,li=li,co=co)
 }
-#############################################################################
+###########################################################################
